@@ -111,8 +111,9 @@ class Projects(enum.Enum):
     )
     VB = ("NeuropixelVisualBehavior",)
     TTN = ('TaskTrainedNetworksNeuropixel',)
-
-    def latest_session(self, session_type: Literal['ephys', 'hab', 'behavior'] = 'ephys') -> int | None:
+    NP = ('NeuropixelPlatformDevelopment',)
+    
+    def get_latest_session(self, session_type: Literal['ephys', 'hab', 'behavior'] = 'ephys') -> int | None:
         "Lims session id for latest session for all child projects."
         for _ in self.value:
             session_id = Project(_).state.get(f'latest_{session_type}')
@@ -120,9 +121,18 @@ class Projects(enum.Enum):
                 return session_id
         return None
     
-    latest_ephys = functools.partialmethod(latest_session, 'ephys')
-    latest_hab = functools.partialmethod(latest_session, 'hab')
-    latest_behavior = functools.partialmethod(latest_session, 'behavior')
+    get_latest_ephys = functools.partialmethod(get_latest_session, 'ephys')
+    get_latest_hab = functools.partialmethod(get_latest_session, 'hab')
+    get_latest_behavior = functools.partialmethod(get_latest_session, 'behavior')
+    
+    @property
+    def state(self) -> MutableMapping[str, Any]:
+        try:
+            return State(str(self.name))
+        except Exception as exc:
+            logger.error("Failed to load `%r.state`: %r", self, exc)
+        return {}
+    
     
 class Project(InfoBaseClass):
     
@@ -146,4 +156,11 @@ class Project(InfoBaseClass):
         except Exception as exc:
             logger.error("Failed to load `%r.state`: %r", self, exc)
         return {}
-
+    
+    @property
+    def parent(self) -> Projects | None:
+        "Parent project if it exists."
+        for _ in Projects:
+            if self.id in _.value:
+                return _
+        return None
