@@ -7,20 +7,21 @@ from typing import Optional
 
 import np_logging
 
-from np_session.session import Session
+import np_session.session
+
 from np_session.components.paths import INCOMING_ROOT as DEFAULT_INCOMING_ROOT
 
 logger = np_logging.getLogger(__name__)
 
 def get_files(  
-    session: Optional[str | pathlib.Path | Session] = None,
+    session: Optional[str | pathlib.Path | np_session.session.Session] = None,
     files: Optional[dict] = None,
     platform_json: Optional[pathlib.Path] = None,
 ) -> list[pathlib.Path]:
     """By default, gets paths for the files in the platform D1 json on npexp for the Session provided."""
     if session and not (files or platform_json): # if session is provided, use it to get the platform json
-        if not isinstance(session, Session):
-            session = Session(session)
+        if not isinstance(session, np_session.session.Session):
+            session = np_session.session.Session(session)
     platform_json = next(session.npexp_path.glob('*platformD1*.json'), None)
       
     if not platform_json:
@@ -38,7 +39,7 @@ def get_files(
     return [platform_json.parent / tuple(file.values())[0] for file in files.values()]
 
 def check_files(
-    session: Optional[str | pathlib.Path | Session] = None,
+    session: Optional[str | pathlib.Path | np_session.session.Session] = None,
     files: Optional[dict] = None,
     platform_json: Optional[pathlib.Path] = None,
     ) -> list[tuple[pathlib.Path, bool]]:
@@ -50,7 +51,7 @@ def check_files(
     return results
 
 def write_trigger_file(
-    session: Session, 
+    session: np_session.session.Session, 
     incoming_dir: pathlib.Path = DEFAULT_INCOMING_ROOT,
     trigger_dir: pathlib.Path = DEFAULT_INCOMING_ROOT / "trigger",
     override: bool = False,
