@@ -210,7 +210,7 @@ def get_files_manifest(
     - project_name: corresponds to a manifet template
     - session_str: [lims_id]_[mouse_id]_[session_id], will replace a placeholder in a manifest template
     """
-    if session_type is 'D0':
+    if session_type == 'D0':
         return {'files': {f'ephys_raw_data_probe_{letter}': 
         {'directory_name': f'{session_str}_probe{"ABC" if letter in "ABC" else "DEF"}'} for letter in 'ABCDEF'}}
         
